@@ -2,6 +2,8 @@ from ScopusWp.scopus.data import ScopusPublication, ScopusAuthor, ScopusAffiliat
 
 import ScopusWp.config as cfg
 
+from ScopusWp.scopus.config import ScopusConfig
+
 from ScopusWp.scopus.config import NAME
 
 import queue
@@ -20,7 +22,7 @@ class ScopusBaseController:
     """
     def __init__(self):
         # Getting the config instance for the project
-        self.config = cfg.Config.get_instance()
+        self.config = ScopusConfig.get_instance()
 
         # Getting the logger for the the scopus part of the project
         scopus_logger_id = cfg.SCOPUS_LOGGING_EXTENSION
@@ -1084,61 +1086,6 @@ class ScopusPublicationProcessor:
         return current_level
 
 
-class ScopusWorker(threading.Thread):
-
-    def __init__(self, queue):
-        threading.Thread.__init__(self)
-        self.scopus_controller = ScopusController()
-
-        self.logger = logging.getLogger(NAME)
-
-        self.queue = queue  # type: queue.Queue
-        self.id = None
-        self.publication = None
-        self.active = False
-
-    def assign_publication(self, scopus_id):
-        self.active = True
-        self.id = scopus_id
-
-    def run(self):
-        while True:
-            if self.id is not None:
-                try:
-                    self.publication = self.scopus_controller.get_publication(self.id)
-                    self.queue.put(self.publication)
-                except ConnectionError:
-                    self.logger.warning('[Web] Connection Error for {}'.format(self.id))
-                finally:
-                    self.active = False
-                    self.id = None
-            else:
-                time.sleep(0.1)
-
-
-class ScopusWorkerPool:
-
-    def __init__(self, worker_count=4):
-        self.publication_queue = queue.Queue(1000)
-        self.workers = []
-        for i in range(worker_count):
-            worker = ScopusWorker(self.publication_queue)
-            self.workers.append(worker)
-            worker.start()
-        self.ids = []
-
-    def assign_publications(self, id_list):
-        self.ids = id_list
-
-    def fetch(self):
-        while len(self.ids) != 0:
-            inactive_workers = list(filter(lambda x: not x.active, self.workers))
-            for worker in inactive_workers:
-                if len(self.ids) != 0:
-                    worker.assign_publication(self.ids.pop())
-            if self.publication_queue.qsize() != 0:
-                yield self.publication_queue.get()
-
 
 if __name__ == '__main__':
 
